# agilicus-api
Agilicus API endpoints

The `agilicus_api` package is automatically generated by the [OpenAPI Generator](https://openapi-generator.tech) project:

- API version: 2020.04.15
- Package version: 1.13.1
- Build package: org.openapitools.codegen.languages.PythonClientCodegen
For more information, please visit [https://www.agilicus.com](https://www.agilicus.com)

## Requirements.

Python 2.7 and 3.4+

## Installation & Usage

This python library package is generated without supporting files like setup.py or requirements files

To be able to use it, you will need these dependencies in your own package that uses this library:

* urllib3 >= 1.15
* six >= 1.10
* certifi
* python-dateutil

## Getting Started

In your own code, to use this library to connect and interact with agilicus-api,
you can run the following:

```python
from __future__ import print_function
import time
import agilicus_api
from agilicus_api.rest import ApiException
from pprint import pprint

configuration = agilicus_api.Configuration()
# Configure Bearer authorization (JWT): token-valid
configuration.access_token = 'YOUR_BEARER_TOKEN'

# Defining host is optional and default to https://api.agilicus.com
configuration.host = "https://api.agilicus.com"
# Enter a context with an instance of the API client
with agilicus_api.ApiClient(configuration) as api_client:
    # Create an instance of the API class
    api_instance = agilicus_api.ApplicationServicesApi(api_client)
    application_service = agilicus_api.ApplicationService() # ApplicationService | 

    try:
        # Create an ApplicationService
        api_response = api_instance.create_application_service(application_service)
        pprint(api_response)
    except ApiException as e:
        print("Exception when calling ApplicationServicesApi->create_application_service: %s\n" % e)
    
```

## Documentation for API Endpoints

All URIs are relative to *https://api.agilicus.com*

Class | Method | HTTP request | Description
------------ | ------------- | ------------- | -------------
*ApplicationServicesApi* | [**create_application_service**](agilicus_api/docs/ApplicationServicesApi.md#create_application_service) | **POST** /v2/application_services | Create an ApplicationService
*ApplicationServicesApi* | [**delete_application_service**](agilicus_api/docs/ApplicationServicesApi.md#delete_application_service) | **DELETE** /v2/application_services/{app_service_id} | Remove an ApplicationService
*ApplicationServicesApi* | [**get_application_service**](agilicus_api/docs/ApplicationServicesApi.md#get_application_service) | **GET** /v2/application_services/{app_service_id} | Get a single ApplicationService
*ApplicationServicesApi* | [**list_application_services**](agilicus_api/docs/ApplicationServicesApi.md#list_application_services) | **GET** /v2/application_services | Get a subset of the ApplicationServices
*ApplicationServicesApi* | [**replace_application_service**](agilicus_api/docs/ApplicationServicesApi.md#replace_application_service) | **PUT** /v2/application_services/{app_service_id} | Create or update an Application Service.
*ApplicationsApi* | [**add_config**](agilicus_api/docs/ApplicationsApi.md#add_config) | **POST** /v2/applications/{app_id}/environments/{env_name}/configs | Add an environment configuration row
*ApplicationsApi* | [**create_application**](agilicus_api/docs/ApplicationsApi.md#create_application) | **POST** /v2/applications | Create an application
*ApplicationsApi* | [**delete_application**](agilicus_api/docs/ApplicationsApi.md#delete_application) | **DELETE** /v2/applications/{app_id} | Remove an application
*ApplicationsApi* | [**delete_config**](agilicus_api/docs/ApplicationsApi.md#delete_config) | **DELETE** /v2/applications/{app_id}/environments/{env_name}/configs/{env_config_id} | Remove an environment configuration
*ApplicationsApi* | [**get_application**](agilicus_api/docs/ApplicationsApi.md#get_application) | **GET** /v2/applications/{app_id} | Get a application
*ApplicationsApi* | [**get_config**](agilicus_api/docs/ApplicationsApi.md#get_config) | **GET** /v2/applications/{app_id}/environments/{env_name}/configs/{env_config_id} | Get environment configuration
*ApplicationsApi* | [**get_environment**](agilicus_api/docs/ApplicationsApi.md#get_environment) | **GET** /v2/applications/{app_id}/environments/{env_name} | Get an environment
*ApplicationsApi* | [**list_applications**](agilicus_api/docs/ApplicationsApi.md#list_applications) | **GET** /v2/applications | Get applications
*ApplicationsApi* | [**list_configs**](agilicus_api/docs/ApplicationsApi.md#list_configs) | **GET** /v2/applications/{app_id}/environments/{env_name}/configs | Get all environment configuration
*ApplicationsApi* | [**list_environment_configs_all_apps**](agilicus_api/docs/ApplicationsApi.md#list_environment_configs_all_apps) | **GET** /v2/environment_configs | Get all environment configuration for a given organisation.
*ApplicationsApi* | [**replace_application**](agilicus_api/docs/ApplicationsApi.md#replace_application) | **PUT** /v2/applications/{app_id} | Create or update an application
*ApplicationsApi* | [**replace_config**](agilicus_api/docs/ApplicationsApi.md#replace_config) | **PUT** /v2/applications/{app_id}/environments/{env_name}/configs/{env_config_id} | Update environment configuration
*ApplicationsApi* | [**replace_environment**](agilicus_api/docs/ApplicationsApi.md#replace_environment) | **PUT** /v2/applications/{app_id}/environments/{env_name} | Update an environment
*AuditsApi* | [**list_audits**](agilicus_api/docs/AuditsApi.md#list_audits) | **GET** /v1/audits | View audit records
*DiagnosticsApi* | [**list_logs**](agilicus_api/docs/DiagnosticsApi.md#list_logs) | **GET** /v1/diagnostics/logs | Retrieve application logs
*FilesApi* | [**add_file**](agilicus_api/docs/FilesApi.md#add_file) | **POST** /v1/files | upload a file
*FilesApi* | [**delete_file**](agilicus_api/docs/FilesApi.md#delete_file) | **DELETE** /v1/files/{file_id} | Delete a File
*FilesApi* | [**get_download**](agilicus_api/docs/FilesApi.md#get_download) | **GET** /v1/files_download/{file_id} | Download File
*FilesApi* | [**get_file**](agilicus_api/docs/FilesApi.md#get_file) | **GET** /v1/files/{file_id} | Get File metadata
*FilesApi* | [**list_files**](agilicus_api/docs/FilesApi.md#list_files) | **GET** /v1/files | Query Files
*FilesApi* | [**replace_file**](agilicus_api/docs/FilesApi.md#replace_file) | **PUT** /v1/files/{file_id} | Update a file
*GroupsApi* | [**add_group_member**](agilicus_api/docs/GroupsApi.md#add_group_member) | **POST** /v1/groups/{group_id}/members | Add a group member
*GroupsApi* | [**create_group**](agilicus_api/docs/GroupsApi.md#create_group) | **POST** /v1/groups | Create a group
*GroupsApi* | [**delete_group**](agilicus_api/docs/GroupsApi.md#delete_group) | **DELETE** /v1/groups/{group_id} | Delete a group
*GroupsApi* | [**delete_group_member**](agilicus_api/docs/GroupsApi.md#delete_group_member) | **DELETE** /v1/groups/{group_id}/members/{member_id} | Remove a group member
*GroupsApi* | [**get_group**](agilicus_api/docs/GroupsApi.md#get_group) | **GET** /v1/groups/{group_id} | Get a group
*GroupsApi* | [**list_groups**](agilicus_api/docs/GroupsApi.md#list_groups) | **GET** /v1/groups | Get all groups
*GroupsApi* | [**replace_group**](agilicus_api/docs/GroupsApi.md#replace_group) | **PUT** /v1/groups/{group_id} | update a group
*IssuersApi* | [**create_client**](agilicus_api/docs/IssuersApi.md#create_client) | **POST** /v1/clients | Create a client
*IssuersApi* | [**create_issuer**](agilicus_api/docs/IssuersApi.md#create_issuer) | **POST** /v1/issuers/issuer_roots | Create an issuer
*IssuersApi* | [**delete_client**](agilicus_api/docs/IssuersApi.md#delete_client) | **DELETE** /v1/clients/{client_id} | Delete a client
*IssuersApi* | [**delete_root**](agilicus_api/docs/IssuersApi.md#delete_root) | **DELETE** /v1/issuers/issuer_roots/{issuer_id} | Delete an Issuer
*IssuersApi* | [**get_client**](agilicus_api/docs/IssuersApi.md#get_client) | **GET** /v1/clients/{client_id} | Get client
*IssuersApi* | [**get_issuer**](agilicus_api/docs/IssuersApi.md#get_issuer) | **GET** /v1/issuers/issuer_extensions/{issuer_id} | Get issuer
*IssuersApi* | [**get_root**](agilicus_api/docs/IssuersApi.md#get_root) | **GET** /v1/issuers/issuer_roots/{issuer_id} | Get issuer
*IssuersApi* | [**list_clients**](agilicus_api/docs/IssuersApi.md#list_clients) | **GET** /v1/clients | Query Clients
*IssuersApi* | [**list_issuer_roots**](agilicus_api/docs/IssuersApi.md#list_issuer_roots) | **GET** /v1/issuers/issuer_roots | Query Issuers
*IssuersApi* | [**list_issuers**](agilicus_api/docs/IssuersApi.md#list_issuers) | **GET** /v1/issuers/issuer_extensions | Query Issuers
*IssuersApi* | [**replace_client**](agilicus_api/docs/IssuersApi.md#replace_client) | **PUT** /v1/clients/{client_id} | Update a client
*IssuersApi* | [**replace_issuer**](agilicus_api/docs/IssuersApi.md#replace_issuer) | **PUT** /v1/issuers/issuer_extensions/{issuer_id} | Update an issuer
*IssuersApi* | [**replace_root**](agilicus_api/docs/IssuersApi.md#replace_root) | **PUT** /v1/issuers/issuer_roots/{issuer_id} | Update an issuer
*MetricsApi* | [**list_active_users**](agilicus_api/docs/MetricsApi.md#list_active_users) | **GET** /v1/metrics/{org_id}/active_users | View number of active users
*MetricsApi* | [**list_top_users**](agilicus_api/docs/MetricsApi.md#list_top_users) | **GET** /v1/metrics/{org_id}/top_users | View top users
*OrganisationsApi* | [**create_blocking_upgrade_orgs_task**](agilicus_api/docs/OrganisationsApi.md#create_blocking_upgrade_orgs_task) | **POST** /v1/orgs/upgrade | utility to upgrade organisations
*OrganisationsApi* | [**create_org**](agilicus_api/docs/OrganisationsApi.md#create_org) | **POST** /v1/orgs | Create an organisation
*OrganisationsApi* | [**create_sub_org**](agilicus_api/docs/OrganisationsApi.md#create_sub_org) | **POST** /v1/orgs/{org_id}/orgs | Create a sub organisation
*OrganisationsApi* | [**delete_sub_org**](agilicus_api/docs/OrganisationsApi.md#delete_sub_org) | **DELETE** /v1/orgs/{org_id}/orgs/{sub_org_id} | Delete a sub organisation
*OrganisationsApi* | [**get_org**](agilicus_api/docs/OrganisationsApi.md#get_org) | **GET** /v1/orgs/{org_id} | Get a single organisation
*OrganisationsApi* | [**list_orgs**](agilicus_api/docs/OrganisationsApi.md#list_orgs) | **GET** /v1/orgs | Get all organisations
*OrganisationsApi* | [**list_sub_orgs**](agilicus_api/docs/OrganisationsApi.md#list_sub_orgs) | **GET** /v1/orgs/{org_id}/orgs | Get all sub organisations
*OrganisationsApi* | [**replace_org**](agilicus_api/docs/OrganisationsApi.md#replace_org) | **PUT** /v1/orgs/{org_id} | Create or update an organisation
*ServicesApi* | [**create_service**](agilicus_api/docs/ServicesApi.md#create_service) | **POST** /v2/services | Create a Service
*ServicesApi* | [**delete_service**](agilicus_api/docs/ServicesApi.md#delete_service) | **DELETE** /v2/services/{service_id} | Remove a Service
*ServicesApi* | [**get_service**](agilicus_api/docs/ServicesApi.md#get_service) | **GET** /v2/services/{service_id} | Get a single Service
*ServicesApi* | [**list_services**](agilicus_api/docs/ServicesApi.md#list_services) | **GET** /v2/services | Get a subset of the Services
*ServicesApi* | [**replace_service**](agilicus_api/docs/ServicesApi.md#replace_service) | **PUT** /v2/services/{service_id} | Create or update a Service.
*TokensApi* | [**create_introspect_token**](agilicus_api/docs/TokensApi.md#create_introspect_token) | **POST** /v1/tokens/introspect | Introspect a token
*TokensApi* | [**create_reissued_token**](agilicus_api/docs/TokensApi.md#create_reissued_token) | **POST** /v1/tokens/reissue | Issue a new token from another
*TokensApi* | [**create_revoke_token_task**](agilicus_api/docs/TokensApi.md#create_revoke_token_task) | **POST** /v1/tokens/revoke | Revoke a token
*TokensApi* | [**create_token**](agilicus_api/docs/TokensApi.md#create_token) | **POST** /v1/tokens | Create a token
*TokensApi* | [**list_tokens**](agilicus_api/docs/TokensApi.md#list_tokens) | **GET** /v1/tokens | Query tokens
*UsersApi* | [**create_user**](agilicus_api/docs/UsersApi.md#create_user) | **POST** /users | Create a user
*UsersApi* | [**delete_user**](agilicus_api/docs/UsersApi.md#delete_user) | **DELETE** /v1/orgs/{org_id}/users/{user_id} | Remove a user from an organisation
*UsersApi* | [**get_user**](agilicus_api/docs/UsersApi.md#get_user) | **GET** /users/{user_id} | Get a single user
*UsersApi* | [**list_all_user_orgs**](agilicus_api/docs/UsersApi.md#list_all_user_orgs) | **GET** /users/{user_id}/orgs | Return all organisations a user has been assigned to
*UsersApi* | [**list_all_user_roles**](agilicus_api/docs/UsersApi.md#list_all_user_roles) | **GET** /users/{user_id}/render_roles | Return all roles for a user
*UsersApi* | [**list_user_guids**](agilicus_api/docs/UsersApi.md#list_user_guids) | **GET** /users_ids | Get a list of all user GUIDs
*UsersApi* | [**list_user_permissions**](agilicus_api/docs/UsersApi.md#list_user_permissions) | **GET** /users/{user_id}/host_permissions | Return the user&#39;s host permissions
*UsersApi* | [**list_users**](agilicus_api/docs/UsersApi.md#list_users) | **GET** /users | Get all users
*UsersApi* | [**replace_user**](agilicus_api/docs/UsersApi.md#replace_user) | **PUT** /users/{user_id} | Create or update a user
*UsersApi* | [**replace_user_role**](agilicus_api/docs/UsersApi.md#replace_user_role) | **PUT** /users/{user_id}/roles | Create or update a user role
*WhoamiApi* | [**create_whoami**](agilicus_api/docs/WhoamiApi.md#create_whoami) | **POST** /v1/whoami | login through whoami


## Documentation For Models

 - [AddGroupMemberRequest](agilicus_api/docs/AddGroupMemberRequest.md)
 - [Application](agilicus_api/docs/Application.md)
 - [ApplicationAssignment](agilicus_api/docs/ApplicationAssignment.md)
 - [ApplicationService](agilicus_api/docs/ApplicationService.md)
 - [ApplicationServiceAssignment](agilicus_api/docs/ApplicationServiceAssignment.md)
 - [Audit](agilicus_api/docs/Audit.md)
 - [CreateTokenRequest](agilicus_api/docs/CreateTokenRequest.md)
 - [Definition](agilicus_api/docs/Definition.md)
 - [Environment](agilicus_api/docs/Environment.md)
 - [EnvironmentConfig](agilicus_api/docs/EnvironmentConfig.md)
 - [EnvironmentConfigVar](agilicus_api/docs/EnvironmentConfigVar.md)
 - [File](agilicus_api/docs/File.md)
 - [FileSummary](agilicus_api/docs/FileSummary.md)
 - [FileUpload](agilicus_api/docs/FileUpload.md)
 - [Group](agilicus_api/docs/Group.md)
 - [GroupData](agilicus_api/docs/GroupData.md)
 - [GroupMember](agilicus_api/docs/GroupMember.md)
 - [HostPermissions](agilicus_api/docs/HostPermissions.md)
 - [Issuer](agilicus_api/docs/Issuer.md)
 - [IssuerClient](agilicus_api/docs/IssuerClient.md)
 - [JSONBodyConstraint](agilicus_api/docs/JSONBodyConstraint.md)
 - [ListActiveUsersResponse](agilicus_api/docs/ListActiveUsersResponse.md)
 - [ListApplicationServicesResponse](agilicus_api/docs/ListApplicationServicesResponse.md)
 - [ListApplicationsResponse](agilicus_api/docs/ListApplicationsResponse.md)
 - [ListAuditsResponse](agilicus_api/docs/ListAuditsResponse.md)
 - [ListConfigsResponse](agilicus_api/docs/ListConfigsResponse.md)
 - [ListEnvironmentConfigsResponse](agilicus_api/docs/ListEnvironmentConfigsResponse.md)
 - [ListFilesResponse](agilicus_api/docs/ListFilesResponse.md)
 - [ListGroupsResponse](agilicus_api/docs/ListGroupsResponse.md)
 - [ListIssuerClientsResponse](agilicus_api/docs/ListIssuerClientsResponse.md)
 - [ListIssuerExtensionsResponse](agilicus_api/docs/ListIssuerExtensionsResponse.md)
 - [ListIssuerRootsResponse](agilicus_api/docs/ListIssuerRootsResponse.md)
 - [ListLogsResponse](agilicus_api/docs/ListLogsResponse.md)
 - [ListOrgsResponse](agilicus_api/docs/ListOrgsResponse.md)
 - [ListServicesResponse](agilicus_api/docs/ListServicesResponse.md)
 - [ListTokensResponse](agilicus_api/docs/ListTokensResponse.md)
 - [ListTopUsersResponse](agilicus_api/docs/ListTopUsersResponse.md)
 - [ListUserGuidsResponse](agilicus_api/docs/ListUserGuidsResponse.md)
 - [ListUsersResponse](agilicus_api/docs/ListUsersResponse.md)
 - [Log](agilicus_api/docs/Log.md)
 - [Organisation](agilicus_api/docs/Organisation.md)
 - [OrganisationAdmin](agilicus_api/docs/OrganisationAdmin.md)
 - [RawToken](agilicus_api/docs/RawToken.md)
 - [RenderedQueryParameter](agilicus_api/docs/RenderedQueryParameter.md)
 - [RenderedRule](agilicus_api/docs/RenderedRule.md)
 - [RenderedRuleBody](agilicus_api/docs/RenderedRuleBody.md)
 - [ReplaceUserRoleRequest](agilicus_api/docs/ReplaceUserRoleRequest.md)
 - [Role](agilicus_api/docs/Role.md)
 - [RoleList](agilicus_api/docs/RoleList.md)
 - [Roles](agilicus_api/docs/Roles.md)
 - [Rule](agilicus_api/docs/Rule.md)
 - [RuleQueryBody](agilicus_api/docs/RuleQueryBody.md)
 - [RuleQueryBodyJSON](agilicus_api/docs/RuleQueryBodyJSON.md)
 - [RuleQueryParameter](agilicus_api/docs/RuleQueryParameter.md)
 - [Service](agilicus_api/docs/Service.md)
 - [StorageRegion](agilicus_api/docs/StorageRegion.md)
 - [TimeIntervalMetrics](agilicus_api/docs/TimeIntervalMetrics.md)
 - [TimeValidity](agilicus_api/docs/TimeValidity.md)
 - [Token](agilicus_api/docs/Token.md)
 - [TokenReissueRequest](agilicus_api/docs/TokenReissueRequest.md)
 - [TokenRevoke](agilicus_api/docs/TokenRevoke.md)
 - [TokenValidity](agilicus_api/docs/TokenValidity.md)
 - [User](agilicus_api/docs/User.md)
 - [UserIdentity](agilicus_api/docs/UserIdentity.md)
 - [UserInfo](agilicus_api/docs/UserInfo.md)
 - [UserMemberOf](agilicus_api/docs/UserMemberOf.md)
 - [UserMetrics](agilicus_api/docs/UserMetrics.md)
 - [UserSummary](agilicus_api/docs/UserSummary.md)
 - [WhoamiRequest](agilicus_api/docs/WhoamiRequest.md)
 - [WhoamiResponse](agilicus_api/docs/WhoamiResponse.md)


## Documentation For Authorization


## token-valid

- **Type**: Bearer authentication (JWT)


## Author

dev@agilicus.com


